==> smasher-1.0.5-source.tar.gz: smasher-1.0.5/src/smasherMain.h <==
#ifndef SMASHERMAIN_H
#define SMASHERMAIN_H

#include <vector>
#include <map>
#include "undohistory.h"
#include <wx/string.h>
#include <wx/mediactrl.h>

class EffectsGrid;
class MonochromeGrid;
class SettingsBook;
template<class T> class SmashGridMapper;
class SmashThread;
class Wav16Smash;
class WaveWindow;

class wxAuiManager;
class wxAuiToolBar;
class wxBoxSizer;
class wxFileConfig;
class wxFrame;

class wxMenu;
class wxSpinCtrl;
class wxStreamToTextRedirector;
class wxTextCtrl;

class wxCloseEvent;
class wxCommandEvent;
class wxCriticalSection;
class wxDropFilesEvent;
class wxGridEvent;
class wxIdleEvent;
class wxSpinEvent;
class wxTimerEvent;
class wxTreebookEvent;
class wxUpdateUIEvent;
class wxTimer;
class MediaTimer;
class LoopTimer;

class smasherFrame: public wxFrame
{
public:
    smasherFrame(wxFrame *frame, const wxString& title);
    ~smasherFrame();

    void loadState ( const wxString& state, bool newData = false );
    std::vector<wxString> *getDefaultStates();
    void OnRestoreDefault(wxCommandEvent& event);

    void swapMediaCtrls ();
    wxMediaCtrl *getCurrentMediaCtrl();
    wxMediaCtrl *getAlternativeMediaCtrl();
    MediaTimer *getCurrentMediaTimer();
    void startLoopTimer();
    void notifyPlaybackTime();
    void setLoopLatency ( int i );
    wxAuiManager *getManager();

    void DoClearOrder ( MonochromeGrid *m );
    void DoSliceOrder1ToN ( MonochromeGrid *m );
private:
    enum
    {
        ID_OPEN,
        ID_SAVE,
        ID_PLAY_SMASHED,
        ID_FX_ORDER_CLEAR,
        ID_FX_ORDER_SHUFFLE_ALL,
        ID_FX_ORDER_SHUFFLE_BY_KEY,
        ID_FX_ORDER_STICKY,
        ID_LOOP,
        ID_LOOP_SMASHED,
        ID_PLAY,
        ID_PAUSE,
        ID_SETTINGS_CHANGED,
        ID_SHOW_EFFECTS,
        ID_SHOW_LOG,
        ID_SHOW_PLOT,
        ID_SHOW_SETTINGS,
        ID_SHOW_TRANSPORT_ONLY,
        ID_SLICE_ORDER_1_TO_N,
        ID_SLICE_ORDER_CLEAR,
        ID_SLICE_ORDER_N_TO_1,
        ID_SLICE_ORDER_SHUFFLE_ALL,
        ID_SLICE_ORDER_SHUFFLE_BY_KEY,
        ID_SLICE_ORDER_ROTATE_LEFT,
        ID_SLICE_ORDER_ROTATE_RIGHT,
        ID_SLICE_NO_CHANGE,
        ID_STOP,
        ID_STOP_SMASHED,
        ID_RESTORE_DEFAULT,
        ID_TIMER,
        ID_VOLUME_SLIDER,
        ID_MEDIACTRL,
        ID_MEDIACTRL_ALT,
        ID_LOAD_MACHINE_STATE,
        ID_SAVE_MACHINE_STATE,
        ID_LOOP_TIMER,
        ID_TOGGLE_PLAY
    };

    enum statusFields {
        STATUS_MAIN = 0,
        STATUS_CHANNELS,
        STATUS_SAMPLERATE,
        STATUS_PLAYBACK,
        STATUS_TIMER,
        STATUS_END
    };

    wxCriticalSection criticalSection;
    size_t csRefCounter;
    wxFileConfig *config;
    wxString appDir, fileIn, perspectiveMemory, stateMemory;
    std::vector<wxString> effectsVector, tempFiles;
    std::vector<wxString> *defaultStates;
    std::map<wxString, wxString> smashedFileMap;
    std::basic_string<double> lPlotData, rPlotData;
    wxSize sizeMemory;
    wxAuiManager *manager;
    wxAuiToolBar *toolbar, *mapToolbar, *effectsToolbar;
    wxMediaCtrl *mediaCtrl, *mediaCtrlAlt, *currentMediaCtrl, *alternativeMediaCtrl;
    wxMenu *fileMenu, *editMenu, *helpMenu, *transportMenu, *viewMenu;
    wxSpinCtrl *sliceNoSpinControl;
    SettingsBook *settingsBook;
    UndoHistory history;
    MonochromeGrid *mapGrid;
    EffectsGrid *effectsGrid;
    wxTextCtrl *logText, *positionCtrl;
    Wav16Smash *w;
    WaveWindow *lPlot, *rPlot;
    MediaTimer *mediaTimer, *mediaTimerAlt, *currentMediaTimer;
    LoopTimer *loopTimer;
    wxTimer *timer;
    SmashThread *thread;
    wxStreamToTextRedirector *redirect;
#ifndef __WXMSW__
    wxSlider *volumeSlider;
#else
    wxSpinCtrl *volumeSlider;
#endif
    bool loopState, loopSmashedState, pauseState, orderStickyState,
    viewEffectsState, viewLogState, viewPlotState, viewSettingsState, viewTransportOnlyState,
    smashRequired, threadAbort, pathValid, alternativeCtrlIsCurrentCtrl, isPlaySmashedButton, closeDown;
    int threadState, sliceNoMemory, loopLatency, gridColumnMemory;
    std::string smashMessage;
    size_t idleCounter;

    std::vector<int> gridHighlightVector;

    void addTransformers( std::vector<size_t>& posVector );
    void DoFxOrderShuffleAll ( );
    void DoFxOrderShuffleByKey ( );
    void DoFxOrderSticky();
    void DoIdle();
    void DoLoop();
    void DoLoopSmashed ();
    bool DoOpen( const wxString& wideFile );
    void DoPause();
    bool DoPlaySmashed ( int requestedSliceNo = -1);
    void DoShowEffects ();
    void DoShowLog ();
    void DoShowPlot ();
    void DoShowSettings();
    void DoShowTransportOnly();
    void DoSliceNoChange();
    void DoSliceOrderNTo1 ( MonochromeGrid *m );
    void DoSliceOrderShuffleAll ( MonochromeGrid *m );
    void DoSliceOrderShuffleByKey ( MonochromeGrid *m );
    void DoStop();
    void DoVolumeChanged();
    void handleMp3 ( std::string& file );
    void initGridHighlightVector();
    void OnAbout(wxCommandEvent& event);
    void OnClose(wxCloseEvent& event);
#ifdef __WXMSW__
    void OnDropFiles ( wxDropFilesEvent& event );
#endif
    void OnGridColLeftClick(wxGridEvent& event);
    void OnFxOrderClear (wxCommandEvent& event);
    void OnFxOrderShuffleAll (wxCommandEvent& event);
    void OnFxOrderShuffleByKey (wxCommandEvent& event );
    void OnFxOrderSticky ( wxCommandEvent& event );
    void OnIdle ( wxIdleEvent& event );
    void OnKeyDown( wxKeyEvent& event );
    void OnLoop( wxCommandEvent& event );
    void OnLoopSmashed( wxCommandEvent& event );
    void OnMediaFinished( wxMediaEvent& event );
    void OnMediaLoaded( wxMediaEvent& event );
    void OnMediaStateChanged( wxMediaEvent& event );

    void DoMediaFinished();
    void DoMediaLoaded();
    void DoMediaPlay();

    void OnPause ( wxCommandEvent& event );
    void OnOpen(wxCommandEvent& event);
    void OnPlay(wxCommandEvent& event);
    void OnPlaySmashed(wxCommandEvent& event);
    void OnQuit(wxCommandEvent& event);
    void OnRadioBoxChanged ( wxCommandEvent& event );
    void OnRedo ( wxCommandEvent& event );
    void OnSave(wxCommandEvent& event);
    void OnLoadMachineState ( wxCommandEvent& event);
    void OnSaveMachineState ( wxCommandEvent& event);
    void OnSettingsChanged (wxTreebookEvent& event);
    void OnShowEffects (wxCommandEvent& event);
    void OnShowLog (wxCommandEvent& event);
    void OnShowPlot (wxCommandEvent& event);
    void OnShowSettings (wxCommandEvent& event);
    void OnShowTransportOnly (wxCommandEvent& event);
    void OnSliceNoChange (wxSpinEvent& event);
    void OnSliceOrder1ToN (wxCommandEvent& event);
    void OnSliceOrderClear (wxCommandEvent& event);
    void OnSliceOrderNTo1 (wxCommandEvent& event);
    void OnSliceOrderShuffleAll (wxCommandEvent& event);
    void OnSliceOrderShuffleByKey (wxCommandEvent& event);
    void OnSliceOrderRotateLeft (wxCommandEvent& event);
    void OnSliceOrderRotateRight (wxCommandEvent& event);
    void OnStop(wxCommandEvent& event);
    void OnTogglePlay(wxCommandEvent& event);
    void OnUndo ( wxCommandEvent& event );
    void OnUpdateRedo ( wxUpdateUIEvent& event );
    void OnUpdateUndo ( wxUpdateUIEvent& event );
    void OnUpdateThreadRunning ( wxUpdateUIEvent& event );
    void OnUpdatePaneMaximized ( wxUpdateUIEvent& event );
#ifndef __WXMSW__
    void OnVolumeChanged ( wxScrollEvent& event );
#else
    void OnVolumeChanged ( wxSpinEvent& event );
#endif
    bool paneIsMaximized();
    bool play(wxString& fileName /*, bool loop */ );
    wxString saveState ( );
    void smashAsync();
    void smashSync();
    void updatePlotArea ();
    void updateTitle ( const wxString& s );
    void waitForThreadsToFinish ();
    void OnTimer ( wxTimerEvent& e );
    DECLARE_EVENT_TABLE()
};


#endif

==> smasher-1.0.8-source.tar.gz: smasher-1.0.8/src/smasherMain.h <==
#ifndef SMASHERMAIN_H
#define SMASHERMAIN_H

#include <vector>
#include <map>
#include "undohistory.h"
#include <wx/string.h>
#include <wx/mediactrl.h>
#include <wx/docview.h>

class EffectsGrid;
class MonochromeGrid;
class ProgressGrid;
class SettingsBook;
template<class T> class SmashGridMapper;
class SmashThread;
class Wav16Smash;
class WaveWindow;

class wxAuiManager;
class wxAuiManagerEvent;
class wxAuiToolBar;
class wxBoxSizer;
class wxFileConfig;
class wxFrame;
class wxHtmlWindow;

class wxMenu;
class wxSpinCtrl;
class wxStreamToTextRedirector;
class wxTextCtrl;

class wxCloseEvent;
class wxCommandEvent;
class wxCriticalSection;
class wxDropFilesEvent;
class wxGridEvent;
class wxIdleEvent;
class wxSpinEvent;
class wxTimerEvent;
class wxTreebookEvent;
class wxUpdateUIEvent;
class wxTimer;
class MediaTimer;
class LoopTimer;

class smasherFrame: public wxFrame
{
public:
    smasherFrame(wxFrame *frame, const wxString& title);
    ~smasherFrame();

    void loadState ( const wxString& state, bool newData = false );
    std::vector<wxString> *getDefaultStates();
    void OnRestoreDefault(wxCommandEvent& event);

    void swapMediaCtrls ();
    wxMediaCtrl *getCurrentMediaCtrl();
    wxMediaCtrl *getAlternativeMediaCtrl();
    MediaTimer *getCurrentMediaTimer();
    void startLoopTimer();
    void notifyPlaybackTime();
    void setLoopLatency ( int i );
    wxAuiManager *getManager();
    bool getViewSettingsState();
    bool getChangedWhilePlaying();
    void setChangedWhilePlaying( bool b );

    void DoClearOrder ( MonochromeGrid *m );
    void DoSliceOrder1ToN ( MonochromeGrid *m );
    bool DoPlaySmashed ( int requestedSliceNo = -1);
private:
    enum
    {
        ID_OPEN,
        ID_SAVE,
        ID_SAVE_SONG,
        ID_PLAY_SMASHED,
        ID_FX_ORDER_CLEAR,
        /*ID_FX_ORDER_SHUFFLE_ALL,
        ID_FX_ORDER_SHUFFLE_BY_KEY,*/
        ID_FX_ORDER_STICKY,
        ID_LOOP,
        ID_LOOP_SMASHED,
        ID_PLAY,
        ID_PAUSE,
        ID_SETTINGS_CHANGED,
        ID_SHOW_EFFECTS,
        ID_SHOW_LOG,
        ID_SHOW_PLOT,
        ID_SHOW_SETTINGS,
        ID_SHOW_TRANSPORT_ONLY,
        ID_SHOW_HELP,
        ID_SLICE_ORDER_1_TO_N,
        ID_SLICE_ORDER_CLEAR,
        ID_SLICE_ORDER_N_TO_1,
        ID_SLICE_ORDER_SHUFFLE_ALL,
        ID_SLICE_ORDER_SHUFFLE_BY_KEY,
        ID_SLICE_ORDER_ROTATE_LEFT,
        ID_SLICE_ORDER_ROTATE_RIGHT,
        ID_SLICE_NO_CHANGE,
        ID_STOP,
        ID_STOP_SMASHED,
        ID_RESTORE_DEFAULT,
        ID_TIMER,
        ID_VOLUME_SLIDER,
        ID_MEDIACTRL,
        ID_MEDIACTRL_ALT,
        ID_LOAD_MACHINE_STATE,
        ID_SAVE_MACHINE_STATE,
        ID_LOOP_TIMER,
        ID_TOGGLE_PLAY,
        ID_CHECK_FOR_UPDATES
    };

    enum statusFields {
        STATUS_MAIN = 0,
        STATUS_CHANNELS,
        STATUS_SAMPLERATE,
        STATUS_PLAYBACK,
        STATUS_TIMER,
        STATUS_END
    };

    wxCriticalSection criticalSection;
    size_t csRefCounter;
    wxFileConfig *config;
    wxString appDir, fileIn, perspectiveMemory, stateMemory;
    std::vector<wxString> effectsVector, tempFiles;
    std::vector<wxString> *defaultStates;
    std::map<wxString, wxString> smashedFileMap;
    std::basic_string<double> lPlotData, rPlotData;
    wxSize sizeMemory;
    wxAuiManager *manager;
    wxAuiToolBar *toolbar, *mapToolbar, *effectsToolbar;
    wxMediaCtrl *mediaCtrl, *mediaCtrlAlt, *currentMediaCtrl, *alternativeMediaCtrl;
    wxMenu *fileMenu, *editMenu, *helpMenu, *transportMenu, *viewMenu;
    wxSpinCtrl *sliceNoSpinControl;
    SettingsBook *settingsBook;
    wxHtmlWindow *helpPane;
    UndoHistory history;
    MonochromeGrid *mapGrid;
    EffectsGrid *effectsGrid;
    ProgressGrid *progressGrid;
    wxTextCtrl *logText, *positionCtrl;
    Wav16Smash *w;
    WaveWindow *lPlot, *rPlot;
    MediaTimer *mediaTimer, *mediaTimerAlt, *currentMediaTimer;
    LoopTimer *loopTimer;
    wxTimer *timer;
    SmashThread *thread;
    wxStreamToTextRedirector *redirect;
#ifndef __WXMSW__
    wxSlider *volumeSlider;
#else
    wxSpinCtrl *volumeSlider;
#endif
    bool loopState, loopSmashedState, pauseState, slicePlayState, orderStickyState,
    viewEffectsState, viewPlotState,viewLogState, viewSettingsState, viewTransportOnlyState, viewHelpState,
    smashRequired, threadAbort, pathValid, alternativeCtrlIsCurrentCtrl, isPlaySmashedButton, helpPageLoaded,
    closeDown, changedWhilePlaying;
    int threadState, sliceNoMemory, loopLatency, gridColumnMemory;
    std::string smashMessage;
    size_t idleCounter;
    wxFileHistory fileHistory;

    void addTransformers( Wav16Smash *wav, std::vector<size_t>& posVector );
    void OnBuildSong( wxCommandEvent &event );
    void OnCheckForUpdates( wxCommandEvent &event );
    void DoFxOrderShuffleAll ( );
    void DoFxOrderShuffleByKey ( );
    void DoFxOrderSticky();
    void DoIdle();
    void DoLoop();
    void DoLoopSmashed ();
    bool DoOpen( Wav16Smash *wav, const wxString& wideFile );
    void DoPause();
    void DoShowEffects ();
    void DoShowProgressGrid();
    void DoShowLog ();
    void DoShowPlot ();
    void DoShowSettings();
    void DoShowTransportOnly();
    void DoShowHelp();
    void DoSliceNoChange();
    void DoSliceOrderNTo1 ( MonochromeGrid *m );
    void DoSliceOrderShuffleAll ( MonochromeGrid *m );
    void DoSliceOrderShuffleByKey ( MonochromeGrid *m );
    void DoStop();
    void DoVolumeChanged();
    bool DoLoadMachineState ( const wxString& path );
    void handleMp3 ( std::string& file );
    void initHelpPane();
    void OnAbout(wxCommandEvent& event);
    void OnClose(wxCloseEvent& event);
#ifdef __WXMSW__
    void OnDropFiles ( wxDropFilesEvent& event );
#endif
    void OnGridColLeftClick(wxGridEvent& event);
    void OnFxOrderClear (wxCommandEvent& event);
    void OnFxOrderSticky ( wxCommandEvent& event );
    void OnIdle ( wxIdleEvent& event );
    void OnKeyDown( wxKeyEvent& event );
    void OnLoop( wxCommandEvent& event );
    void OnLoopSmashed( wxCommandEvent& event );
    void OnMediaFinished( wxMediaEvent& event );
    void OnMediaLoaded( wxMediaEvent& event );
    void OnMediaStateChanged( wxMediaEvent& event );

    void DoMediaFinished();
    void DoMediaLoaded();
    void DoMediaPlay();

    void OnHistoryFile ( wxCommandEvent& event );

    void OnPause ( wxCommandEvent& event );
    void OnOpen(wxCommandEvent& event);
    void OnPlay(wxCommandEvent& event);
    void OnPlaySmashed(wxCommandEvent& event);
    void OnQuit(wxCommandEvent& event);
    void OnRadioBoxChanged ( wxCommandEvent& event );
    void OnRedo ( wxCommandEvent& event );
    void OnSave(wxCommandEvent& event);
    void OnPaneClose( wxAuiManagerEvent& event );

    void OnLoadMachineState ( wxCommandEvent& event);
    void OnSaveMachineState ( wxCommandEvent& event);
    void OnSettingsChanged (wxTreebookEvent& event);
    void OnShowLog (wxCommandEvent& event);
    void OnShowSettings (wxCommandEvent& event);
    void OnShowTransportOnly (wxCommandEvent& event);
    void OnShowHelp ( wxCommandEvent& event);
    void OnSliceNoChange (wxSpinEvent& event);
    void OnSliceOrder1ToN (wxCommandEvent& event);
    void OnSliceOrderClear (wxCommandEvent& event);
    void OnSliceOrderNTo1 (wxCommandEvent& event);
    void OnSliceOrderShuffleAll (wxCommandEvent& event);
    void OnSliceOrderShuffleByKey (wxCommandEvent& event);
    void OnSliceOrderRotateLeft (wxCommandEvent& event);
    void OnSliceOrderRotateRight (wxCommandEvent& event);
    void OnStop(wxCommandEvent& event);
    void OnTogglePlay(wxCommandEvent& event);
    void OnUndo ( wxCommandEvent& event );
    void OnUpdateRedo ( wxUpdateUIEvent& event );
    void OnUpdateUndo ( wxUpdateUIEvent& event );
    void OnUpdateThreadRunning ( wxUpdateUIEvent& event );
    void OnUpdatePaneMaximized ( wxUpdateUIEvent& event );
#ifndef __WXMSW__
    void OnVolumeChanged ( wxScrollEvent& event );
#else
    void OnVolumeChanged ( wxSpinEvent& event );
#endif
    bool paneIsMaximized();
    bool play(wxString& fileName /*, bool loop */ );
    wxString saveState ( );
    void smashAsync();
    void smashSync( Wav16Smash *wav );
    void updateFileMenu ( bool deleteExisting = true );
    void updatePlotArea ();
    void updateTitle ( const wxString& s );
    void waitForThreadsToFinish ();
    void OnTimer ( wxTimerEvent& e );
    DECLARE_EVENT_TABLE()
};


#endif
